@@ -235,7 +235,7 @@ SetBitsFunction::SetBitsFunction() : MathFunction("setbits", 4, 6) {
 	setArgumentDefinition(4, new IntegerArgument());
 	setArgumentDefinition(5, new IntegerArgument("", ARGUMENT_MIN_MAX_NONE, true, true, INTEGER_TYPE_UINT));
 	setDefaultValue(5, "0");
-	setArgumentDefinition(5, new BooleanArgument());
+	setArgumentDefinition(6, new BooleanArgument());
 	setDefaultValue(6, "0");
 }
 int SetBitsFunction::calculate(MathStructure &mstruct, const MathStructure &vargs, const EvaluationOptions &eo) {
@@ -267,7 +267,7 @@ int SetBitsFunction::calculate(MathStructure &mstruct, const MathStructure &varg
 		nrbits.exp2();
 		bits = nrbits.uintValue();
 	}
-	if(bits > 0 && max_index == bits && (b_signed || vargs[0].number().isNegative()) && (vargs[3].number().bitGet(max_index) != vargs[0].number().isNegative())) {
+	if(bits > 0 && max_index == bits && (b_signed || vargs[0].number().isNegative()) && (vargs[3].number().bitGet(last_pos - first_pos) != vargs[0].number().isNegative())) {
 		PrintOptions po;
 		po.base = BASE_BINARY;
 		po.base_display = BASE_DISPLAY_NONE;
@@ -411,10 +411,11 @@ bool calculate_replace2(MathStructure &m, const MathStructure &mfrom1, const Mat
 	}
 	return b;
 }
-bool calculate_userfunctions2(MathStructure &m, const MathStructure &x_mstruct, const MathStructure &x_mstruct2, const EvaluationOptions &eo) {
+bool calculate_userfunctions2(MathStructure &m, const MathStructure &x_mstruct, const MathStructure &x_mstruct2, const EvaluationOptions &eo, size_t depth = 1) {
+	if(!check_recursive_function_depth(depth)) return false;
 	bool b_ret = false;
 	for(size_t i = 0; i < m.size(); i++) {
-		if(calculate_userfunctions2(m[i], x_mstruct, x_mstruct2, eo)) {
+		if(calculate_userfunctions2(m[i], x_mstruct, x_mstruct2, eo, depth + 1)) {
 			m.childUpdated(i + 1);
 			b_ret = true;
 		}
@@ -423,7 +424,7 @@ bool calculate_userfunctions2(MathStructure &m, const MathStructure &x_mstruct,
 		if(!m.contains(x_mstruct, true) && !m.contains(x_mstruct2, true) && !m.containsFunctionId(FUNCTION_ID_RAND, true, true, true) && !m.containsFunctionId(FUNCTION_ID_RANDN, true, true, true) && !m.containsFunctionId(FUNCTION_ID_RAND_POISSON, true, true, true)) {
 			if(m.calculateFunctions(eo, false)) {
 				b_ret = true;
-				calculate_userfunctions2(m, x_mstruct, x_mstruct2, eo);
+				calculate_userfunctions2(m, x_mstruct, x_mstruct2, eo, depth + 1);
 			}
 		} else if(m.function()->subtype() == SUBTYPE_USER_FUNCTION && m.function()->condition().empty()) {
 			bool b = true;
@@ -441,7 +442,7 @@ bool calculate_userfunctions2(MathStructure &m, const MathStructure &x_mstruct,
 				}
 			}
 			if(b && m.calculateFunctions(eo, false)) {
-				calculate_userfunctions2(m, x_mstruct, x_mstruct2, eo);
+				calculate_userfunctions2(m, x_mstruct, x_mstruct2, eo, depth + 1);
 				b_ret = true;
 			}
 		}
