@@ -18,13 +18,16 @@
 #include "MathStructure-support.h"
 
 #include <locale.h>
-#include <unistd.h>
+#ifdef _MSC_VER
+#	include <sys/utime.h>
+#else
+#	include <unistd.h>
+#	include <utime.h>
+#endif
 #include <time.h>
-#include <utime.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <dirent.h>
 #include <vector>
 
 using std::string;
@@ -271,7 +274,7 @@ bool Calculator::plotVectors(PlotParameters *param, const vector<MathStructure>
 	for(size_t i = 0; i < y_vectors.size(); i++) {
 		yim_vectors.push_back(m_undefined);
 		if(!y_vectors[i].isUndefined()) {
-			for(size_t i2 = 0; i2 < y_vectors[i].size() - 1; i2++) {
+			for(size_t i2 = 0; i2 + 1 < y_vectors[i].size(); i2++) {
 				if(y_vectors[i][i2].isNumber() && y_vectors[i][i2].number().hasImaginaryPart()) {
 					if(y_vectors[i][i2 + 1].isNumber() && y_vectors[i][i2 + 1].number().hasImaginaryPart()) {
 						yim_vectors[i].clearVector();
